@@ -1,4 +1,6 @@
-import random
+from random import *
+
+random = Random
 
 ### time, os, sys, math, datetime, random, json, asyncio, datetime
 
